Skip to main contentModule node_util
Source - get_image_node_from_path
- Get image node in the way, and return the rest of path.
- get_node_without_parse
- get a certain node without parsing all node in the way
- get_resolved_uol_path
- Get resolved uol path, it will resolve
.. and . in path. - parse_node
- Just wrap around of
node.write().unwrap().parse(&node) - resolve_childs_parent
- Make sure WzNode tree’s all node has correct parent.
- resolve_inlink
- Resolve a
_inlink path, a _inlink path always start from a WzImage. - resolve_outlink
- Resolve a
_outlink path, a _outlink path always start from Wz’s data root(a.k.a Base.wz). - resolve_uol
- Make a uol node become valid node, second argument is optional,
it prevent the parent is the WzImage while it currently parsing causing the deadlock.